@@ -1,12 +1,12 @@
 /*
   This file is Copyright © 1994-1995 Olivier Montanuy,
                Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+               Copyright © 2006-2019 contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /*
@@ -579,7 +579,7 @@ void COMiwad(int argc, const char *argv[])
 void COMmake(int argc, const char *argv[])
 {
     const char *wadinf, *wadout;
-    if (WadInfOk == false) {
+    if (!WadInfOk) {
         MakeFileName(WadInf, DataDir, "", "", "WADINFO", "TXT");
     }
     if (argc <= 2) {
@@ -597,7 +597,7 @@ void COMmake(int argc, const char *argv[])
 void COMxtra(int argc, const char *argv[])
 {
     const char *wadinf, *wadin;
-    if (WadInfOk == false) {
+    if (!WadInfOk) {
         MakeFileName(WadInf, DataDir, "", "", "WADINFO", "TXT");
     }
     if (argc <= 1) {
@@ -647,7 +647,7 @@ void COMusedidx(int argc, const char *argv[])
 {
     const char *wadinf, *wadin;
     cusage_t *cusage = NULL;
-    if (WadInfOk == false) {
+    if (!WadInfOk) {
         /* Not used anyway */
         MakeFileName(WadInf, DataDir, "", "", "WADINFO", "TXT");
     }
@@ -983,15 +983,14 @@ int main(int argc, char *argv_non_const[])
             int gotit = 0;
             const char **w;
             for (w = wads; *w != NULL; w++) {
-                if (MakeFileName(MainWAD, ".", "", "", *w, "wad") == true) {
+                if (MakeFileName(MainWAD, ".", "", "", *w, "wad")) {
                     gotit = 1;
                     break;
                 }
             }
             if (!gotit) {
                 for (w = wads; *w != NULL; w++) {
-                    if (MakeFileName(MainWAD, DoomDir, "", "", *w, "wad")
-                        == true) {
+                    if (MakeFileName(MainWAD, DoomDir, "", "", *w, "wad")) {
                         gotit = 1;
                         break;
                     }
@@ -1001,8 +1000,7 @@ int main(int argc, char *argv_non_const[])
             if (!gotit) {
                 for (w = wads; *w != NULL; w++) {
                     if (MakeFileName
-                        (MainWAD, "/usr/share/games/doom", "", "", *w,
-                         "wad") == true) {
+                        (MainWAD, "/usr/share/games/doom", "", "", *w, "wad")) {
                         gotit = 1;
                         break;
                     }
