@@ -1,12 +1,12 @@
 /*
   This file is Copyright © 1994-1995 Olivier Montanuy,
                Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+               Copyright © 2006-2019 contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "deutex.h"
@@ -65,7 +65,7 @@ static bool XTRbmpSave(int16_t * pinsrX, int16_t * pinsrY,
         Bug("EX47", "Invalid img type %d", (int) Picture);
     }
     res = MakeFileName(file, DataDir, dir, "", name, extens);
-    if ((WSafe == true) && (res == true)) {
+    if (res && WSafe) {
         Warning("EX48", "Will not overwrite file %s", file);
         return true;
     }
@@ -75,12 +75,50 @@ static bool XTRbmpSave(int16_t * pinsrX, int16_t * pinsrY,
     res =
         PICsaveInFile(file, type, buffer, size, pinsrX, pinsrY, Picture,
                       name, cusage);
-    if (res == true)
+    if (res)
         Detail("EX49", "Saved picture as %s", fname(file));
     free(buffer);
     return res;
 }
 
+/*
+** determine image format of a lump within TX_START..TX_END.
+** returns a PICXXX value, defaulting to PICNONE when no
+** specific image format matches the lump data.
+*/
+static IMGTYPE XTRpicFormat(struct WADDIR *entry, struct WADINFO *info)
+{
+    int32_t start = entry->start;
+    int32_t size = entry->size;
+
+    unsigned char buf[16];
+
+    memset(buf, 0, sizeof(buf));
+
+    if (size > 16)
+        size = 16;
+
+    WADRseek(info, start);
+    WADRreadBytes(info, buf, size);
+
+    /* PNG? */
+    if (buf[0] == 0x89 &&
+        buf[1] == 'P' && buf[2] == 'N' && buf[3] == 'G' &&
+        buf[4] == 0x0D && buf[5] == 0x0A && buf[6] == 0x1A) {
+        return PICPNG;
+    }
+
+    /* JPEG? */
+    if (buf[0] == 0xFF && buf[1] == 0xD8 &&
+        buf[2] == 0xFF && buf[3] >= 0xE0 &&
+        ((buf[6] == 'J' && buf[7] == 'F') ||
+         (buf[6] == 'E' && buf[7] == 'x'))) {
+        return PICJPEG;
+    }
+
+    return PICNONE;
+}
+
 /*
 ** extract entries from a WAD
 **
@@ -259,7 +297,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
             switch (piden[p] & EMASK) {
             case ELEVEL:
             case EMAP:
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "LEVELS", "");
                     TXTaddEmptyLine(TXT);
                     TXTaddComment(TXT, "List of levels");
@@ -274,7 +312,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                     res =
                         MakeFileName(file, DataDir, "LEVELS", "",
                                      pdir[p].name, "WAD");
-                    if ((WSafe == true) && (res == true))
+                    if (res && WSafe)
                         Warning("EX11", "Will not overwrite file %s",
                                 file);
                     else {
@@ -302,7 +340,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == ELUMP) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "LUMPS", "");
                     TXTaddEmptyLine(TXT);
                     TXTaddComment(TXT, "List of data Lumps");
@@ -324,13 +362,12 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                                        DataDir, "LUMPS", &pwad, Picture,
                                        WSafe, cusage);
                     }
-                    if (res != true) {
+                    if (!res) {
                         /*normal lumps */
                         res =
                             MakeFileName(file, DataDir, "LUMPS", "",
                                          pdir[p].name, "LMP");
-                        if ((WSafe == true)
-                            && (res == true)) {
+                        if (res && WSafe) {
                             Warning("EX16", "Will not overwrite file %s",
                                     file);
                         } else {
@@ -353,7 +390,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         EntryFound = false;
         for (p = 0; p < pnb; p++) {
             if (piden[p] == ETEXTUR + 1) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "TEXTURES", "");
                     EntryFound = true;
                 }
@@ -374,7 +411,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                         MakeFileName(file, DataDir, "TEXTURES", "", name,
                                      "TXT");
                 }
-                if ((WSafe == true) && (res == true)) {
+                if (res && WSafe) {
                     Warning("EX21", "Will not overwrite file %s", file);
                 } else {
                     buffer = (char *) Malloc(pdir[p].size);
@@ -391,7 +428,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         }
         for (p = 0; p < pnb; p++) {
             if (piden[p] == ETEXTUR + 2) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "TEXTURES", "");
                     EntryFound = true;
                 }
@@ -403,7 +440,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 res =
                     MakeFileName(file, DataDir, "TEXTURES", "",
                                  pdir[p].name, "TXT");
-                if ((WSafe == true) && (res == true)) {
+                if (res && WSafe) {
                     Warning("EX22", "Will not overwrite file %s", file);
                 } else {
                     buffer = (char *) Malloc(pdir[p].size);
@@ -420,6 +457,62 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         }
     }
 
+    /*
+    ** TX_START textures
+    */
+    if ((select & BTEXTUR) && cusage == NULL) {
+        Phase("EX70", "Extracting TX_START textures...");
+        EntryFound = false;
+        for (p = 0; p < pnb; p++) {
+            if (piden[p] == ETXSTART) {
+                IMGTYPE detect_type;
+
+                if (!EntryFound) {
+                    MakeDir(file, DataDir, "TX_START", "");
+                    TXTaddEmptyLine(TXT);
+                    TXTaddComment(TXT, "List of TX_START textures");
+                    TXTaddSection(TXT, "tx_start");
+                    EntryFound = true;
+                }
+
+                ostart = pwad.dir[p].start;
+                osize = pwad.dir[p].size;
+                insrX = insrY = 0;
+
+                detect_type = XTRpicFormat(&pdir[p], &pwad);
+
+                if (detect_type == PICNONE) {
+                    /* assume DOOM patch format */
+                    if (!XTRbmpSave(&insrX, &insrY, &pdir[p], PGRAPH,
+                        DataDir, "TX_START", &pwad, Picture, WSafe,
+                        cusage)) {
+                            Warning("EX71", "Failed to write TX_START texture %s",
+                                    lump_name(pwad.dir[p].name));
+                    } else {
+                        TXTaddEntry(TXT, pdir[p].name, NULL, INVALIDINT,
+                                    INVALIDINT, false, false);
+                    }
+                } else {
+                    /* write PNG or JPEG as a raw file, no conversion */
+                    const char *ext = "PNG";
+                    if (detect_type == PICJPEG)
+                        ext = "JPG";
+
+                    res = MakeFileName(file, DataDir, "TX_START", "",
+                                       pdir[p].name, ext);
+                    if (WSafe && res) {
+                        Warning("EX73", "Will not overwrite file %s", file);
+                    } else {
+                        WADRsaveEntry(&pwad, p, file);
+                        Detail("EX74", "Saved lump as   %s", fname(file));
+                    }
+
+                    TXTaddEntry(TXT, pdir[p].name, NULL, 1, 0, false, true);
+                }
+            }
+        }
+    }
+
     /*
     ** SOUNDS
     */
@@ -429,7 +522,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == ESOUND) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "SOUNDS", "");
                     TXTaddEmptyLine(TXT);
                     TXTaddComment(TXT, "List of Sounds");
@@ -448,8 +541,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                         res =
                             MakeFileName(file, DataDir, "SOUNDS", "",
                                          pdir[p].name, "TXT");
-                        if ((WSafe == true)
-                            && (res == true)) {
+                        if (res && WSafe) {
                             Warning("EX26", "Will not overwrite file %s",
                                     file);
                         } else {
@@ -479,8 +571,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                         res =
                             MakeFileName(file, DataDir, "SOUNDS", "",
                                          pdir[p].name, extens);
-                        if ((WSafe == true)
-                            && (res == true)) {
+                        if (res && WSafe) {
                             Warning("EX29", "Will not overwrite file %s",
                                     fname(file));
                         } else {
@@ -514,7 +605,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == EMUSIC) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     MakeDir(file, DataDir, "MUSICS", "");
                     TXTaddEmptyLine(TXT);
                     TXTaddComment(TXT, "List of Musics");
@@ -535,7 +626,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                         res = MakeFileName(file, DataDir, "MUSICS", "",
                                            pdir[p].name, "MID");
                     }
-                    if ((WSafe == true) && (res == true)) {
+                    if (res && WSafe) {
                         Warning("EX33", "Will not overwrite file %s",
                                 fname(file));
                     } else {
@@ -558,7 +649,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == EGRAPHIC) {
-                if (EntryFound != true && cusage == NULL) {
+                if (!EntryFound && cusage == NULL) {
                     MakeDir(file, DataDir, "GRAPHICS", "");
                 }
                 if ((ostart == pwad.dir[p].start)
@@ -570,9 +661,8 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                     osize = pwad.dir[p].size;
                     if (XTRbmpSave
                         (&insrX, &insrY, &pdir[p], PGRAPH, DataDir,
-                         "GRAPHICS", &pwad, Picture, WSafe,
-                         cusage) == true) {
-                        if (EntryFound != true) {
+                         "GRAPHICS", &pwad, Picture, WSafe, cusage)) {
+                        if (!EntryFound) {
                             TXTaddEmptyLine(TXT);
                             TXTaddComment(TXT,
                                           "List of Pictures (with insertion point)");
@@ -584,7 +674,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                     } else if (XTRbmpSave
                                (&insrX, &insrY, &pdir[p], PFLAT,
                                 DataDir, "LUMPS", &pwad, Picture,
-                                WSafe, cusage) == true) {
+                                WSafe, cusage)) {
                         /*Was saved as graphic lump */
                         char *name = Malloc(sizeof pdir[p].name + 1);
                         sprintf(name, "%.*s", (int) sizeof pdir[p].name,
@@ -593,8 +683,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                         free(name);
                     } else if (cusage == NULL) {
                         if (MakeFileName
-                            (file, DataDir, "LUMPS", "", pdir[p].name,
-                             "LMP") == true) {
+                            (file, DataDir, "LUMPS", "", pdir[p].name, "LMP")) {
                             Warning("EX36", "Will not overwrite file %s",
                                     fname(file));
                         } else {
@@ -625,7 +714,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == ESPRITE) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     if (cusage == NULL)
                         MakeDir(file, DataDir, "SPRITES", "");
                     TXTaddEmptyLine(TXT);
@@ -640,10 +729,10 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 } else {
                     ostart = pwad.dir[p].start;
                     osize = pwad.dir[p].size;
-                    if (XTRbmpSave
+                    if (!XTRbmpSave
                         (&insrX, &insrY, &pdir[p], PSPRIT, DataDir,
                          "SPRITES", &pwad, Picture, WSafe,
-                         cusage) != true) {
+                         cusage)) {
                         Warning("EX41", "Failed to write sprite %s",
                                 lump_name(pwad.dir[p].name));
                     } else {
@@ -662,7 +751,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         Phase("EX45", "Extracting patches...");
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == EPATCH) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     if (cusage == NULL)
                         MakeDir(file, DataDir, "PATCHES", "");
                     TXTaddEmptyLine(TXT);
@@ -672,7 +761,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 }
                 if (XTRbmpSave
                     (&insrX, &insrY, &pdir[p], PPATCH, DataDir, "PATCHES",
-                     &pwad, Picture, WSafe, cusage) == true) {
+                     &pwad, Picture, WSafe, cusage)) {
                     TXTaddEntry(TXT, pdir[p].name, NULL, INVALIDINT,
                                 INVALIDINT, false, false);
                 } else {
@@ -697,7 +786,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
         osize = 0;
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if ((piden[p] & EMASK) == EFLAT) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     if (cusage == NULL)
                         MakeDir(file, DataDir, "FLATS", "");
                     TXTaddEmptyLine(TXT);
@@ -712,9 +801,9 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 } else {
                     ostart = pwad.dir[p].start;
                     osize = pwad.dir[p].size;
-                    if (XTRbmpSave
+                    if (!XTRbmpSave
                         (&insrX, &insrY, &pdir[p], PFLAT, DataDir, "FLATS",
-                         &pwad, Picture, WSafe, cusage) != true) {
+                         &pwad, Picture, WSafe, cusage)) {
                         if (strncmp(pwad.dir[p].name, "F_SKY1", 6) != 0)
                             Warning("EX51", "Failed to write flat %s",
                                     lump_name(pwad.dir[p].name));
@@ -735,7 +824,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
 
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if (piden[p] == type) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     char comment[40];
                     if (cusage == NULL)
                         MakeDir(file, DataDir, entry_type_dir(type), "");
@@ -753,11 +842,11 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 } else {
                     ostart = pwad.dir[p].start;
                     osize = pwad.dir[p].size;
-                    if (XTRbmpSave
+                    if (!XTRbmpSave
                         (&insrX, &insrY, &pdir[p],
                          entry_type_pictype(type), DataDir,
                          entry_type_dir(type), &pwad, Picture, WSafe,
-                         cusage) != true) {
+                         cusage)) {
                         Warning("EX56", "Failed to write %.20s %s",
                                 entry_type_name(type),
                                 lump_name(pwad.dir[p].name));
@@ -779,7 +868,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
 
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if (piden[p] == type) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     char comment[40];
                     if (cusage == NULL)
                         MakeDir(file, DataDir, entry_type_dir(type), "");
@@ -797,11 +886,11 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                 } else {
                     ostart = pwad.dir[p].start;
                     osize = pwad.dir[p].size;
-                    if (XTRbmpSave
+                    if (!XTRbmpSave
                         (&insrX, &insrY, &pdir[p],
                          entry_type_pictype(type), DataDir,
                          entry_type_dir(type), &pwad, Picture, WSafe,
-                         cusage) != true) {
+                         cusage)) {
                         Warning("EX61", "Failed to write %.20s %s",
                                 entry_type_name(type),
                                 lump_name(pwad.dir[p].name));
@@ -823,7 +912,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
 
         for (EntryFound = false, p = 0; p < pnb; p++) {
             if (piden[p] == type) {
-                if (EntryFound != true) {
+                if (!EntryFound) {
                     char comment[40];
                     if (cusage == NULL)
                         MakeDir(file, DataDir, entry_type_dir(type), "");
@@ -846,7 +935,7 @@ void XTRextractWAD(const char *doomwad, const char *DataDir, const char
                             MakeFileName(file, DataDir,
                                          entry_type_dir(type), "",
                                          pdir[p].name, "txt");
-                        if (WSafe == true && res == true) {
+                        if (res && WSafe) {
                             Warning("EX66", "Will not overwrite file %s",
                                     file);
                         } else {
@@ -935,7 +1024,7 @@ void XTRgetEntry(const char *doomwad, const char *DataDir,
     Phase("GE02", "%s: %s: extracting", fname(wadin), lump_name(entry));
     Entry = WADRreadEntry(&pwad, e, &Entrysz);
     /*try graphic */
-    if (Found != true)
+    if (!Found)
         if (Entrysz > 8) {
             switch (Picture) {
 #ifdef HAVE_LIBPNG
@@ -958,7 +1047,7 @@ void XTRgetEntry(const char *doomwad, const char *DataDir,
             MakeFileName(file, DataDir, "", "", Name, extens);
             if (PICsaveInFile
                 (file, PGRAPH, Entry, Entrysz, &insrX, &insrY, Picture,
-                 Name, NULL) == true) {
+                 Name, NULL)) {
                 Info("GE04", "Picture insertion point is (%d,%d)", insrX,
                      insrY);
                 Found = true;
@@ -967,18 +1056,18 @@ void XTRgetEntry(const char *doomwad, const char *DataDir,
             else if ((Entrysz == 0x1000) || (Entrysz == 0x1040)) {
                 if (PICsaveInFile
                     (file, PFLAT, Entry, Entrysz, &insrX, &insrY, Picture,
-                     Name, NULL) == true) {
+                     Name, NULL)) {
                     Found = true;
                 }
             } else if (Entrysz == 64000L) {
                 if (PICsaveInFile
                     (file, PLUMP, Entry, Entrysz, &insrX, &insrY, Picture,
-                     Name, NULL) == true) {
+                     Name, NULL)) {
                     Found = true;
                 }
             }
         }
-    if (Found != true)
+    if (!Found)
         if (peek_i16_le(Entry) == 3)
             if (Entrysz >= 8 + peek_i32_le(Entry + 4)) {
                 /*save as sound */
@@ -994,7 +1083,7 @@ void XTRgetEntry(const char *doomwad, const char *DataDir,
                 SNDsaveSound(file, Entry, Entrysz, Sound, Name);
                 Found = true;
             }
-    if (Found != true) {        /*save as lump */
+    if (!Found) {        /*save as lump */
         MakeFileName(file, DataDir, "", "", Name, "LMP");
         WADRsaveEntry(&pwad, e, file);
     }
