@@ -1,12 +1,12 @@
 /*
   This file is Copyright © 1994-1995 Olivier Montanuy,
                Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+               Copyright © 2006-2019 contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "deutex.h"
@@ -360,7 +360,7 @@ static void IDENTdirSprites(ENTRY * ids, struct WADINFO *info, bool Check)
                 break;          /*last sprite */
             if (info->dir[n].size < 8)
                 break;          /*last sprite */
-            if (Check == true) {
+            if (Check) {
                 if (IDENTgraphic(info, n) == 0)
                     break;
             }
@@ -505,7 +505,7 @@ static void IDENTdirPatches(ENTRY * ids, struct WADINFO *info, char *Pnam,
     ** check for lost patches
     **
     */
-    if (Check == true) {        /*checkif PNAMES is redefined */
+    if (Check) {        /*checkif PNAMES is redefined */
         n = WADRfindEntry(info, "PNAMES");
         if (n >= 0) {
             Pnames = (char *) Malloc(info->dir[n].size);
@@ -532,6 +532,48 @@ static void IDENTdirPatches(ENTRY * ids, struct WADINFO *info, char *Pnam,
     }
 }
 
+/*
+** identifies graphics between TX_START and TX_END
+**
+** Precond: ids contains EZZZZ for unidentified entries
+*/
+static void IDENTdirTXSTART(ENTRY * ids, struct WADINFO *info)
+{
+    int16_t tx_start;
+    int16_t tx_end;
+    int16_t n;
+
+    ident_func = "IDENTdirTXSTART";
+    /*
+    ** check if there are TX_START textures
+    */
+    tx_start = WADRfindEntry(info, "TX_START");
+    tx_end = WADRfindEntry(info, "TX_END");
+
+    if (tx_start < 0 || tx_end < 0) {
+        if (tx_start >= 0)
+            Warning("ITX1", "TX_START exists without matching TX_END");
+        else if (tx_end >= 0)
+            Warning("ITX2", "TX_END exists without matching TX_START");
+        return;
+    }
+    if (tx_end < tx_start) {
+        Warning("ITX3", "TX_START and TX_END occur in wrong order");
+        return;
+    }
+
+    /*
+    ** declare TX_START textures
+    */
+    IDENTsetType(ids, info, tx_start, EVOID);
+    IDENTsetType(ids, info, tx_end, EVOID);
+
+    for (n = tx_end - 1; n > tx_start; n--) {
+        /* format is determined later, when extracting it */
+        IDENTsetType(ids, info, n, ETXSTART);
+    }
+}
+
 /*
 ** Ident unreferenced graphics
 */
@@ -574,7 +616,7 @@ static void IDENTdirGraphics2(ENTRY * ids, struct WADINFO *info,
                 } else if (strncmp(info->dir[n].name, "ST", 2)
                            == 0) {
                     IDENTsetType(ids, info, n, EGRAPHIC);
-                } else if (Check == true) {
+                } else if (Check) {
                     int is_picture = IDENTgraphic(info, n);
                     int is_snea = IDENTsnea(info, n);
                     /* Looks more like a picture */
@@ -640,7 +682,7 @@ static void IDENTdirPCSounds(ENTRY * ids, struct WADINFO *info, bool Check)
         if (ids[n] == EZZZZ) {
             if (info->dir[n].size > 4)  /*works only for DOOM, not HERETIC */
                 if (strncmp(info->dir[n].name, "DP", 2) == 0) {
-                    if (Check == true) {
+                    if (Check) {
                         WADRseek(info, info->dir[n].start);
                         if (WADRreadShort(info) == 0x0)
                             IDENTsetType(ids, info, n, ESNDPC);
@@ -689,7 +731,7 @@ static void IDENTdirSounds(ENTRY * ids, struct WADINFO *info, bool Doom)
                 /*works only for DOOM, not HERETIC */
                 if (strncmp(info->dir[n].name, "DS", 2) == 0) {
                     IDENTsetType(ids, info, n, ESNDWAV);
-                } else if (Doom == false) {
+                } else if (!Doom) {
                     WADRseek(info, info->dir[n].start);
                     if (WADRreadShort(info) == 0x3)
                         if (WADRreadShort(info) == 0x2B11)
@@ -791,7 +833,7 @@ ENTRY *IDENTentriesIWAD(struct WADINFO *info, char *Pnam, int32_t Pnamsz,
     bool Doom = false;
     ENTRY *ids;
     Phase("ID50", "IWAD entry identification...");
-    if (info->ok != true)
+    if (!info->ok)
         Bug("ID51", "IdnOeI");
     ids = (ENTRY *) Malloc((info->ntry) * sizeof(ENTRY));
     if (WADRfindEntry(info, "ENDTEXT") < 0)     /*Not Heretic */
@@ -803,6 +845,7 @@ ENTRY *IDENTentriesIWAD(struct WADINFO *info, char *Pnam, int32_t Pnamsz,
     */
     for (n = 0; n < info->ntry; n++)
         ids[n] = EZZZZ;
+    IDENTdirTXSTART(ids, info); /* fast */
     IDENTdirSprites(ids, info, false);  /*fast */
     IDENTdirFlats(ids, info);   /*fast */
     IDENTdirLevels(ids, info);  /*fast */
@@ -816,7 +859,7 @@ ENTRY *IDENTentriesIWAD(struct WADINFO *info, char *Pnam, int32_t Pnamsz,
     if (WADRfindEntry(info, "ENDSTRF") >= 0) {
         IDENTdirSscripts(ids, info);
     }
-    if (Fast != true) {
+    if (!Fast) {
         IDENTdirSounds(ids, info, Doom);        /*slow! */
         IDENTdirGraphics2(ids, info, true);     /*slow! */
     }
@@ -840,7 +883,7 @@ ENTRY *IDENTentriesPWAD(struct WADINFO * info, char *Pnam, int32_t Pnamsz)
     int16_t n;
     ENTRY *ids;
     Phase("ID10", "PWAD entry identification...");
-    if (info->ok != true)
+    if (!info->ok)
         Bug("ID11", "IdnOeP");
     ids = (ENTRY *) Malloc((info->ntry) * sizeof(ENTRY));
     /*
@@ -848,6 +891,7 @@ ENTRY *IDENTentriesPWAD(struct WADINFO * info, char *Pnam, int32_t Pnamsz)
     */
     for (n = 0; n < info->ntry; n++)
         ids[n] = EZZZZ;
+    IDENTdirTXSTART(ids, info);
     IDENTdirSprites(ids, info, true);
     IDENTdirFlats(ids, info);
     IDENTdirLevels(ids, info);
