@@ -1,12 +1,12 @@
 /*
   This file is Copyright © 1994-1995 Olivier Montanuy,
                Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+               Copyright © 2006-2019 contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "deutex.h"
@@ -300,7 +300,7 @@ int32_t PICsaveInWAD(struct WADINFO * info, char *file, PICTYPE type,
     case PICPNG:
         raw = PNGtoRAW(&rawX, &rawY, file, &altXinsr, &altYinsr);
         /* if the option to use png_offsets is set, use them */
-        if (use_png_offsets == true) {
+        if (use_png_offsets) {
             if (altXinsr != INVALIDINT && altYinsr != INVALIDINT) {
                 Xinsr = altXinsr;
                 Yinsr = altYinsr;
@@ -714,7 +714,7 @@ static char *PICtoRAW(int16_t * prawX, int16_t * prawY, int16_t * pXinsr,
             } else {
                 y = *post++;
                 post_length = *post++;
-                if (is_first_254 == false) {    //if we are in relative offset mode
+                if (!is_first_254) {    //if we are in relative offset mode
                     y += realY;
                     realY = y;
                 }
@@ -1432,7 +1432,7 @@ static char *GIFtoRAW(int16_t * rawX, int16_t * rawY, char *file)
         raw[rawpos] = Idx2Doom[((int16_t) raw[rawpos]) & 0xFF];
     }
     /*unInterlace */
-    if (IntLace == true) {
+    if (IntLace) {
         raw = GIFintlace(raw, Xsz, Ysz);
     }
     *rawX = Xsz;
