@@ -1,12 +1,12 @@
 /*
   This file is Copyright © 1994-1995 Olivier Montanuy,
                Copyright © 1999-2005 André Majorel,
-               Copyright © 2006-2018 contributors to the DeuTex project.
+               Copyright © 2006-2019 contributors to the DeuTex project.
 
   DeuTex incorporates code derived from DEU 5.21 that was put in the
   public domain in 1994 by Raphaël Quinet and Brendon Wyber.
 
-  SPDX-License-Identifier: GPL-2.0+
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 /*
@@ -179,7 +179,7 @@ bool MakeFileName(char file[128], const char *path, const char *dir, const
     char name2[8]; /* AYM 1999-01-13: keep checker happy */
     /* deal with VILE strange name
     ** replace the VILE\
-    ** by          VIL^B
+    ** by          VILE^
     */
     Normalise(name2, name);
 
@@ -257,7 +257,7 @@ void Normalise(char dest[8], const char *src)
     bool pad = false;
     char c = 'A';
     for (n = 0; n < 8; n++) {
-        c = (pad == true) ? '\0' : src[n];
+        c = pad ? '\0' : src[n];
         if (c == '\0')
             pad = true;
         else
@@ -398,7 +398,7 @@ void PrintVerbosity(int16_t level)
 
 void PrintExit(void)
 {
-    if (asFile == true) {
+    if (asFile) {
         fclose(stdout);
         fclose(stderr);
     }
